"use strict";(self.webpackChunkexample_feast_ui=self.webpackChunkexample_feast_ui||[]).push([[63047],{49416:function(e){function n(e){!function(e){function n(e,n){return"___"+e.toUpperCase()+n+"___"}Object.defineProperties(e.languages["markup-templating"]={},{buildPlaceholders:{value:function(t,a,r,o){if(t.language===a){var u=t.tokenStack=[];t.code=t.code.replace(r,(function(e){if("function"===typeof o&&!o(e))return e;for(var r,i=u.length;-1!==t.code.indexOf(r=n(a,i));)++i;return u[i]=e,r})),t.grammar=e.languages.markup}}},tokenizePlaceholders:{value:function(t,a){if(t.language===a&&t.tokenStack){t.grammar=e.languages[a];var r=0,o=Object.keys(t.tokenStack);!function u(i){for(var c=0;c<i.length&&!(r>=o.length);c++){var s=i[c];if("string"===typeof s||s.content&&"string"===typeof s.content){var l=o[r],p=t.tokenStack[l],f="string"===typeof s?s:s.content,g=n(a,l),k=f.indexOf(g);if(k>-1){++r;var m=f.substring(0,k),h=new e.Token(a,e.tokenize(p,t.grammar),"language-"+a,p),d=f.substring(k+g.length),y=[];m&&y.push.apply(y,u([m])),y.push(h),d&&y.push.apply(y,u([d])),"string"===typeof s?i.splice.apply(i,[c,1].concat(y)):s.content=y}}else s.content&&u(s.content)}return i}(t.tokens)}}}})}(e)}e.exports=n,n.displayName="markupTemplating",n.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_markupTemplating.8b953f13.chunk.js.map