"use strict";(self.webpackChunkexample_feast_ui=self.webpackChunkexample_feast_ui||[]).push([[13140],{6359:function(e){function a(e){e.languages.hsts={directive:{pattern:/\b(?:max-age=|includeSubDomains|preload)/,alias:"keyword"},safe:{pattern:/\d{8,}/,alias:"selector"},unsafe:{pattern:/\d{1,7}/,alias:"function"}}}e.exports=a,a.displayName="hsts",a.aliases=[]}}]);
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_hsts.63aebf85.chunk.js.map